from seven_jd.jd.api.rest.VcItemExtPropsFindRequest import VcItemExtPropsFindRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicAppliesFindRequest import VcItemPrimaryPicAppliesFindRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicCreateRequest import VcItemPrimaryPicCreateRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicUpdateRequest import VcItemPrimaryPicUpdateRequest
from seven_jd.jd.api.rest.MiniAppInsertVenderRequest import MiniAppInsertVenderRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicGetRequest import VcItemPrimaryPicGetRequest
from seven_jd.jd.api.rest.VcItemProductsFindRequest import VcItemProductsFindRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicApplyGetRequest import VcItemPrimaryPicApplyGetRequest
from seven_jd.jd.api.rest.CrmMemberSearchNewRequest import CrmMemberSearchNewRequest
from seven_jd.jd.api.rest.VcItemNewProductCreateRequest import VcItemNewProductCreateRequest
from seven_jd.jd.api.rest.VcItemProductApplyDeleteRequest import VcItemProductApplyDeleteRequest
from seven_jd.jd.api.rest.PopOrderCoupondetailRequest import PopOrderCoupondetailRequest
from seven_jd.jd.api.rest.VcItemProductAppliesFindRequest import VcItemProductAppliesFindRequest
from seven_jd.jd.api.rest.TemplateWriteUpdateRequest import TemplateWriteUpdateRequest
from seven_jd.jd.api.rest.PopOrderModifyVenderRemarkRequest import PopOrderModifyVenderRemarkRequest
from seven_jd.jd.api.rest.VcItemProductApplyGetRequest import VcItemProductApplyGetRequest
from seven_jd.jd.api.rest.FollowProductReadQueryForCountByProductIdRequest import FollowProductReadQueryForCountByProductIdRequest
from seven_jd.jd.api.rest.TemplateWriteDeleteRequest import TemplateWriteDeleteRequest
from seven_jd.jd.api.rest.TemplateWriteAddRequest import TemplateWriteAddRequest
from seven_jd.jd.api.rest.ComJdShopJzonecrmGwsJzoneShopJsfServiceGetShopInfoByVenderIdRequest import ComJdShopJzonecrmGwsJzoneShopJsfServiceGetShopInfoByVenderIdRequest
from seven_jd.jd.api.rest.PopPopCommentJsfServiceGetVenderCommentsForJosRequest import PopPopCommentJsfServiceGetVenderCommentsForJosRequest
from seven_jd.jd.api.rest.MfaInnerUserUnifiedAuthenticationRequest import MfaInnerUserUnifiedAuthenticationRequest
from seven_jd.jd.api.rest.VerifyAreaFourIdOpenReqRequest import VerifyAreaFourIdOpenReqRequest
from seven_jd.jd.api.rest.MktSmartstrategyIntelligentisvGetDeliveryChannelRequest import MktSmartstrategyIntelligentisvGetDeliveryChannelRequest
from seven_jd.jd.api.rest.PopPopCommentJsfServiceGetUserCommentVoucherRequest import PopPopCommentJsfServiceGetUserCommentVoucherRequest
from seven_jd.jd.api.rest.MktSmartstrategyIntelligentisvGetCouponBatchRequest import MktSmartstrategyIntelligentisvGetCouponBatchRequest
from seven_jd.jd.api.rest.VcItemPropsFindRequest import VcItemPropsFindRequest
from seven_jd.jd.api.rest.VcItemNewProductCreateV2Request import VcItemNewProductCreateV2Request
from seven_jd.jd.api.rest.VcItemCategoriesFindRequest import VcItemCategoriesFindRequest
from seven_jd.jd.api.rest.VcItemBrandsFindRequest import VcItemBrandsFindRequest
from seven_jd.jd.api.rest.MiniappBrandBenefitReportRequest import MiniappBrandBenefitReportRequest
from seven_jd.jd.api.rest.VcItemProductGetRequest import VcItemProductGetRequest
from seven_jd.jd.api.rest.MfaInnerValidateMsgCodeRequest import MfaInnerValidateMsgCodeRequest
from seven_jd.jd.api.rest.MfaInnerEliminateRiskRequest import MfaInnerEliminateRiskRequest
from seven_jd.jd.api.rest.ConvertFourAreaByDetailStrRequest import ConvertFourAreaByDetailStrRequest
from seven_jd.jd.api.rest.PopCrmGetCustomerPointsRequest import PopCrmGetCustomerPointsRequest
from seven_jd.jd.api.rest.PresaleOrderUpdateOrderGetPresaleOrderByPageRequest import PresaleOrderUpdateOrderGetPresaleOrderByPageRequest
from seven_jd.jd.api.rest.FollowProductComplexWriteFollowRequest import FollowProductComplexWriteFollowRequest
from seven_jd.jd.api.rest.RiskQueryServiceRequest import RiskQueryServiceRequest
from seven_jd.jd.api.rest.MfaInnerSendCodeToMobileRequest import MfaInnerSendCodeToMobileRequest
from seven_jd.jd.api.rest.UserGetUserInfoByXIdRequest import UserGetUserInfoByXIdRequest
from seven_jd.jd.api.rest.VcItemOldProductUpdateV2Request import VcItemOldProductUpdateV2Request
from seven_jd.jd.api.rest.VcItemSaleAttributeSettingsV1GetRequest import VcItemSaleAttributeSettingsV1GetRequest
from seven_jd.jd.api.rest.VcItemOldProductUpdateRequest import VcItemOldProductUpdateRequest
from seven_jd.jd.api.rest.UserGetUserInfoByOpenIdRequest import UserGetUserInfoByOpenIdRequest
from seven_jd.jd.api.rest.VenderShopcategoryFindShopCategoriesByVenderIdRequest import VenderShopcategoryFindShopCategoriesByVenderIdRequest
from seven_jd.jd.api.rest.ImgzoneCategoryQueryRequest import ImgzoneCategoryQueryRequest
from seven_jd.jd.api.rest.VenderCategoryGetFullValidCategoryResultByVenderIdRequest import VenderCategoryGetFullValidCategoryResultByVenderIdRequest
from seven_jd.jd.api.rest.YipOrderAddCartForeignRequest import YipOrderAddCartForeignRequest
from seven_jd.jd.api.rest.ImgzoneCategoryAddRequest import ImgzoneCategoryAddRequest
from seven_jd.jd.api.rest.ImgzoneUserinfoQueryRequest import ImgzoneUserinfoQueryRequest
from seven_jd.jd.api.rest.ImgzonePictureQueryRequest import ImgzonePictureQueryRequest
from seven_jd.jd.api.rest.VenderShopcategoryGetShopCategoryByCidRequest import VenderShopcategoryGetShopCategoryByCidRequest
from seven_jd.jd.api.rest.EliveLiveRoomJsfServiceRequest import EliveLiveRoomJsfServiceRequest
from seven_jd.jd.api.rest.ImgzonePictureUploadRequest import ImgzonePictureUploadRequest
from seven_jd.jd.api.rest.VasSubscribeGetByCodeRequest import VasSubscribeGetByCodeRequest
from seven_jd.jd.api.rest.LockCertsSaveRequest import LockCertsSaveRequest
from seven_jd.jd.api.rest.EdiRealtimeinventoryQueryRequest import EdiRealtimeinventoryQueryRequest
from seven_jd.jd.api.rest.ImgzoneImageUploadRequest import ImgzoneImageUploadRequest
from seven_jd.jd.api.rest.VcItemSpuTemplateGetRequest import VcItemSpuTemplateGetRequest
from seven_jd.jd.api.rest.PopCrmGetPointsDetailRequest import PopCrmGetPointsDetailRequest
from seven_jd.jd.api.rest.UstFlowDataStatisticOnlineRequest import UstFlowDataStatisticOnlineRequest
from seven_jd.jd.api.rest.VasSubscribeGetRequest import VasSubscribeGetRequest
from seven_jd.jd.api.rest.SensitiveEditRequest import SensitiveEditRequest
from seven_jd.jd.api.rest.SensitiveInvalidRequest import SensitiveInvalidRequest
from seven_jd.jd.api.rest.PopOrderSearchRequest import PopOrderSearchRequest
from seven_jd.jd.api.rest.PopCrmGetCouponInfoRequest import PopCrmGetCouponInfoRequest
from seven_jd.jd.api.rest.JosTokenSourceToOpenIdRequest import JosTokenSourceToOpenIdRequest
from seven_jd.jd.api.rest.GroupMarketCreateActivityRequest import GroupMarketCreateActivityRequest
from seven_jd.jd.api.rest.GroupMarketQueryChatGroupsRequest import GroupMarketQueryChatGroupsRequest
from seven_jd.jd.api.rest.VcGetpurchaserlistbypinRequest import VcGetpurchaserlistbypinRequest
from seven_jd.jd.api.rest.VcItemQualificationListFindRequest import VcItemQualificationListFindRequest
from seven_jd.jd.api.rest.VcGetrequisitiondetailbywareidRequest import VcGetrequisitiondetailbywareidRequest
from seven_jd.jd.api.rest.JzoneAddCartItemByPinRequest import JzoneAddCartItemByPinRequest
from seven_jd.jd.api.rest.VcItemDangergoodsGetRequest import VcItemDangergoodsGetRequest
from seven_jd.jd.api.rest.BatchAddSkuAddRequest import BatchAddSkuAddRequest
from seven_jd.jd.api.rest.PopCrmGetMemberInVenderRequest import PopCrmGetMemberInVenderRequest
from seven_jd.jd.api.rest.VcItemFeatureFindRequest import VcItemFeatureFindRequest
from seven_jd.jd.api.rest.VcItemModelFindRequest import VcItemModelFindRequest
from seven_jd.jd.api.rest.MktSmartstrategyIntelligentisvSubmitISVPlanRequest import MktSmartstrategyIntelligentisvSubmitISVPlanRequest
from seven_jd.jd.api.rest.PopCrmQueryCustomerGundogByVenderIdAndPinRequest import PopCrmQueryCustomerGundogByVenderIdAndPinRequest
from seven_jd.jd.api.rest.MktSmartstrategyIntelligentisvGetISVPlanEffectListRequest import MktSmartstrategyIntelligentisvGetISVPlanEffectListRequest
from seven_jd.jd.api.rest.PopOrderGetRequest import PopOrderGetRequest
from seven_jd.jd.api.rest.EdiPoDetailProGetRequest import EdiPoDetailProGetRequest
from seven_jd.jd.api.rest.EdiSdvStockinfoGetRequest import EdiSdvStockinfoGetRequest
from seven_jd.jd.api.rest.EdiSdvCustomerOrderSearchRequest import EdiSdvCustomerOrderSearchRequest
from seven_jd.jd.api.rest.MiniappIsvCreatedMiniAppExperVersionRequest import MiniappIsvCreatedMiniAppExperVersionRequest
from seven_jd.jd.api.rest.PopBeanSendBeanRequest import PopBeanSendBeanRequest
from seven_jd.jd.api.rest.MiniappIsvGetMiniAppDevVersionListRequest import MiniappIsvGetMiniAppDevVersionListRequest
from seven_jd.jd.api.rest.PopPlanAddBeanPlanRequest import PopPlanAddBeanPlanRequest
from seven_jd.jd.api.rest.MiniappIsvRevokeMiniAppCheckVersionRequest import MiniappIsvRevokeMiniAppCheckVersionRequest
from seven_jd.jd.api.rest.PopAccountGetAccountInfoRequest import PopAccountGetAccountInfoRequest
from seven_jd.jd.api.rest.MiniappOrderCancelRequest import MiniappOrderCancelRequest
from seven_jd.jd.api.rest.MiniappCiServiceExperienceRequest import MiniappCiServiceExperienceRequest
from seven_jd.jd.api.rest.OrderInfoDetailQueryN1Request import OrderInfoDetailQueryN1Request
from seven_jd.jd.api.rest.VcQualificationBySkuGetRequest import VcQualificationBySkuGetRequest
from seven_jd.jd.api.rest.OpenLocationRequest import OpenLocationRequest
from seven_jd.jd.api.rest.VcLibraryGetResouceUploadTokenRequest import VcLibraryGetResouceUploadTokenRequest
from seven_jd.jd.api.rest.OrderVenderRemarkQueryByOrderIdRequest import OrderVenderRemarkQueryByOrderIdRequest
from seven_jd.jd.api.rest.GroupMarketQuitGroupRequest import GroupMarketQuitGroupRequest
from seven_jd.jd.api.rest.EdiSdvVendorCommentReplySaveRequest import EdiSdvVendorCommentReplySaveRequest
from seven_jd.jd.api.rest.NewWareVenderSkusQueryRequest import NewWareVenderSkusQueryRequest
from seven_jd.jd.api.rest.MiniappOrderCreatedRequest import MiniappOrderCreatedRequest
from seven_jd.jd.api.rest.PromoUnitAddIsvActivityRequest import PromoUnitAddIsvActivityRequest
from seven_jd.jd.api.rest.PromoUnitGetVenderIsvActivityRequest import PromoUnitGetVenderIsvActivityRequest
from seven_jd.jd.api.rest.GetThirdPdfByOrderIdForVenderRequest import GetThirdPdfByOrderIdForVenderRequest
from seven_jd.jd.api.rest.PromoUnitGetActiveActivityRequest import PromoUnitGetActiveActivityRequest
from seven_jd.jd.api.rest.PopCrmShopGiftCloseShopGiftActivityCallBackRequest import PopCrmShopGiftCloseShopGiftActivityCallBackRequest
from seven_jd.jd.api.rest.PromoUnitModifyIsvActivityRequest import PromoUnitModifyIsvActivityRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCollectCouponRequest import InteractCenterApiServiceWriteCollectCouponRequest
from seven_jd.jd.api.rest.MiniappOrderRefundRequest import MiniappOrderRefundRequest
from seven_jd.jd.api.rest.ShorturlGenerateURLRequest import ShorturlGenerateURLRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponWriteOuterServiceCreateCouponRequest import MarketToolCouponApiServiceCouponWriteOuterServiceCreateCouponRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCollectBeanRequest import InteractCenterApiServiceWriteCollectBeanRequest
from seven_jd.jd.api.rest.SellerCouponWriteLockCouponRequest import SellerCouponWriteLockCouponRequest
from seven_jd.jd.api.rest.MiniappIsvCommitMiniAppCheckVersionRequest import MiniappIsvCommitMiniAppCheckVersionRequest
from seven_jd.jd.api.rest.FceAlphaGetVenderCarrierRequest import FceAlphaGetVenderCarrierRequest
from seven_jd.jd.api.rest.PromoUnitCloseIsvActivityRequest import PromoUnitCloseIsvActivityRequest
from seven_jd.jd.api.rest.PopPopCommentJsfServiceSaveCommentVoteRequest import PopPopCommentJsfServiceSaveCommentVoteRequest
from seven_jd.jd.api.rest.EptOrderGetorderinfobyidRequest import EptOrderGetorderinfobyidRequest
from seven_jd.jd.api.rest.PopPresellMyPresellServiceAddQualification4AppRequest import PopPresellMyPresellServiceAddQualification4AppRequest
from seven_jd.jd.api.rest.CarMemberSkuQueryCarBSkuListByShopIdRequest import CarMemberSkuQueryCarBSkuListByShopIdRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponPageRequest import MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponPageRequest
from seven_jd.jd.api.rest.MarketBdpCartGetPinsBySkuIdRequest import MarketBdpCartGetPinsBySkuIdRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCollectPointsRequest import InteractCenterApiServiceWriteCollectPointsRequest
from seven_jd.jd.api.rest.ShorturlGenerateURLFastestRequest import ShorturlGenerateURLFastestRequest
from seven_jd.jd.api.rest.CmarketToolCouponApiServiceCouponWriteOuterServiceDeleteCouponRequest import CmarketToolCouponApiServiceCouponWriteOuterServiceDeleteCouponRequest
from seven_jd.jd.api.rest.MiniappOrderOrderInfoRequest import MiniappOrderOrderInfoRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponWriteOuterServiceCloseCouponRequest import MarketToolCouponApiServiceCouponWriteOuterServiceCloseCouponRequest
from seven_jd.jd.api.rest.UserCategory3InfoGetRequest import UserCategory3InfoGetRequest
from seven_jd.jd.api.rest.CrmMemberScanRequest import CrmMemberScanRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponDetailsRequest import MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponDetailsRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteWritePersonInfoRequest import InteractCenterApiServiceWriteWritePersonInfoRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSearchRecomListRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSearchRecomListRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadFindRuleByIdAndTypeRequest import InteractCenterApiServiceReadFindRuleByIdAndTypeRequest
from seven_jd.jd.api.rest.SellerCouponWriteCreateRequest import SellerCouponWriteCreateRequest
from seven_jd.jd.api.rest.CreateMemberCardRequest import CreateMemberCardRequest
from seven_jd.jd.api.rest.WriteInteractUserCollectSinglePrizeRequest import WriteInteractUserCollectSinglePrizeRequest
from seven_jd.jd.api.rest.YipOrderGetOrderCustomeInfosRequest import YipOrderGetOrderCustomeInfosRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceCheckHotWordRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceCheckHotWordRequest
from seven_jd.jd.api.rest.DetectionImagesRedLineDetectBatchRequest import DetectionImagesRedLineDetectBatchRequest
from seven_jd.jd.api.rest.PopOrderGetmobilelistRequest import PopOrderGetmobilelistRequest
from seven_jd.jd.api.rest.OrderOperateRequest import OrderOperateRequest
from seven_jd.jd.api.rest.PromoActivityListOperatelogRequest import PromoActivityListOperatelogRequest
from seven_jd.jd.api.rest.MiniappIsvCancelMiniAppExperVersionRequest import MiniappIsvCancelMiniAppExperVersionRequest
from seven_jd.jd.api.rest.SellerCouponWriteCloseRequest import SellerCouponWriteCloseRequest
from seven_jd.jd.api.rest.JosServiceWriteVenderJosShopGiftWriteServiceCloseActivityRequest import JosServiceWriteVenderJosShopGiftWriteServiceCloseActivityRequest
from seven_jd.jd.api.rest.OpenApplyAppointmentRequest import OpenApplyAppointmentRequest
from seven_jd.jd.api.rest.MarketDbpCartCartDataReadServiceGetCarSkuCountRequest import MarketDbpCartCartDataReadServiceGetCarSkuCountRequest
from seven_jd.jd.api.rest.WarehouseOutboundOrderQueryConditionRequest import WarehouseOutboundOrderQueryConditionRequest
from seven_jd.jd.api.rest.CrmGradeUpdateRequest import CrmGradeUpdateRequest
from seven_jd.jd.api.rest.KplOpenPolcenterUnsubscribeorderRequest import KplOpenPolcenterUnsubscribeorderRequest
from seven_jd.jd.api.rest.VcItemSaleAttributeSettingsGetRequest import VcItemSaleAttributeSettingsGetRequest
from seven_jd.jd.api.rest.CrmGradeGetRequest import CrmGradeGetRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadGetOtherCouponInfoRequest import InteractCenterApiServiceReadGetOtherCouponInfoRequest
from seven_jd.jd.api.rest.VenderAuthFindUserRequest import VenderAuthFindUserRequest
from seven_jd.jd.api.rest.ProductConfigSdkServiceSetProductConfigRequest import ProductConfigSdkServiceSetProductConfigRequest
from seven_jd.jd.api.rest.MiniappIsvOnlineMiniAppRelVersionRequest import MiniappIsvOnlineMiniAppRelVersionRequest
from seven_jd.jd.api.rest.CarMerberStoreListStoreInfoRequest import CarMerberStoreListStoreInfoRequest
from seven_jd.jd.api.rest.IsvSignWriteServiceSaveIsvSignStatisticsInfoRequest import IsvSignWriteServiceSaveIsvSignStatisticsInfoRequest
from seven_jd.jd.api.rest.PopCrmShopGiftCreateShopGiftRequest import PopCrmShopGiftCreateShopGiftRequest
from seven_jd.jd.api.rest.GroupMarketCloseActivityRequest import GroupMarketCloseActivityRequest
from seven_jd.jd.api.rest.DropshipDpsPartitionStockMaintainRequest import DropshipDpsPartitionStockMaintainRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCollectGiftRequest import InteractCenterApiServiceWriteCollectGiftRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadGetFreeCouponInfoRequest import InteractCenterApiServiceReadGetFreeCouponInfoRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceSaveRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceSaveRequest
from seven_jd.jd.api.rest.PopAfsSoaRefundapplyQueryPageListRequest import PopAfsSoaRefundapplyQueryPageListRequest
from seven_jd.jd.api.rest.SellerCouponReadGetCouponListRequest import SellerCouponReadGetCouponListRequest
from seven_jd.jd.api.rest.PopVenderGetVenderStatusRequest import PopVenderGetVenderStatusRequest
from seven_jd.jd.api.rest.EdiSdvSalesForecastNumberSearchRequest import EdiSdvSalesForecastNumberSearchRequest
from seven_jd.jd.api.rest.SellerCouponReadGetCouponCountRequest import SellerCouponReadGetCouponCountRequest
from seven_jd.jd.api.rest.EdiSdvSalesForecastNumberGetRequest import EdiSdvSalesForecastNumberGetRequest
from seven_jd.jd.api.rest.EdiInventorySendRequest import EdiInventorySendRequest
from seven_jd.jd.api.rest.YipOrderAddCartForeignGoldRequest import YipOrderAddCartForeignGoldRequest
from seven_jd.jd.api.rest.MiniappCardNoRequest import MiniappCardNoRequest
from seven_jd.jd.api.rest.MiniappIsvGetDevopsPackIdByRequestUuidRequest import MiniappIsvGetDevopsPackIdByRequestUuidRequest
from seven_jd.jd.api.rest.IsvUploadBatchLogRequest import IsvUploadBatchLogRequest
from seven_jd.jd.api.rest.MiniappIsvDelMiniAppDevVersionRequest import MiniappIsvDelMiniAppDevVersionRequest
from seven_jd.jd.api.rest.JosSecretApiReportGetRequest import JosSecretApiReportGetRequest
from seven_jd.jd.api.rest.EdiSdvElectronicPolicySearchRequest import EdiSdvElectronicPolicySearchRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadGiftActivityResultReadServiceFindGiftInfoByIdRequest import InteractCenterApiServiceReadGiftActivityResultReadServiceFindGiftInfoByIdRequest
from seven_jd.jd.api.rest.VcAplsStockBatchGetProdStockInfoRequest import VcAplsStockBatchGetProdStockInfoRequest
from seven_jd.jd.api.rest.VenderVbinfoGetBasicVenderInfoByVenderIdRequest import VenderVbinfoGetBasicVenderInfoByVenderIdRequest
from seven_jd.jd.api.rest.GroupMarketEditActivityRequest import GroupMarketEditActivityRequest
from seven_jd.jd.api.rest.VcQueryshippackagepagelistRequest import VcQueryshippackagepagelistRequest
from seven_jd.jd.api.rest.GetUserEntryWechatGroupTrackRequest import GetUserEntryWechatGroupTrackRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadFindGiftRuleInfoByActivityIdRequest import InteractCenterApiServiceReadFindGiftRuleInfoByActivityIdRequest
from seven_jd.jd.api.rest.VssPromotionQueryunitpromopagelistRequest import VssPromotionQueryunitpromopagelistRequest
from seven_jd.jd.api.rest.QueryAddressListRequest import QueryAddressListRequest
from seven_jd.jd.api.rest.InteractCenterVenderWriteCloseActivityRequest import InteractCenterVenderWriteCloseActivityRequest
from seven_jd.jd.api.rest.PopVenderGetMemberBasicInfoRequest import PopVenderGetMemberBasicInfoRequest
from seven_jd.jd.api.rest.PopOrderFbpGetRequest import PopOrderFbpGetRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSkuListRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSkuListRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceDeleteRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceDeleteRequest
from seven_jd.jd.api.rest.ReadInteractUserFindSinglePrizeCollectInfoRequest import ReadInteractUserFindSinglePrizeCollectInfoRequest
from seven_jd.jd.api.rest.MarketBdpSaleVenderSkuRankQueryRequest import MarketBdpSaleVenderSkuRankQueryRequest
from seven_jd.jd.api.rest.DdPushRequest import DdPushRequest
from seven_jd.jd.api.rest.SellerPromotionCheckRequest import SellerPromotionCheckRequest
from seven_jd.jd.api.rest.SellerPromotionDeleteRequest import SellerPromotionDeleteRequest
from seven_jd.jd.api.rest.PopCustomerJosGetVenderCustomerByBindTimeRequest import PopCustomerJosGetVenderCustomerByBindTimeRequest
from seven_jd.jd.api.rest.MfaUserUnifiedAuthenticationRequest import MfaUserUnifiedAuthenticationRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadFindWorkingGiftActivityByVenderIdRequest import InteractCenterApiServiceReadFindWorkingGiftActivityByVenderIdRequest
from seven_jd.jd.api.rest.JosOauthRpcXidOpenId2XidRequest import JosOauthRpcXidOpenId2XidRequest
from seven_jd.jd.api.rest.JosOauthRpcXidPin2XidRequest import JosOauthRpcXidPin2XidRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCreateGiftActivityRequest import InteractCenterApiServiceWriteCreateGiftActivityRequest
from seven_jd.jd.api.rest.JingdongMiniappApiActivityMiniAppActivityApiUpdateActivityRequest import JingdongMiniappApiActivityMiniAppActivityApiUpdateActivityRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCloseGiftActivityRequest import InteractCenterApiServiceWriteCloseGiftActivityRequest
from seven_jd.jd.api.rest.PromoUnitCloseIsvSignActivityRequest import PromoUnitCloseIsvSignActivityRequest
from seven_jd.jd.api.rest.DropshipDpsSearchoutboundorderRequest import DropshipDpsSearchoutboundorderRequest
from seven_jd.jd.api.rest.VerifySaveRequest import VerifySaveRequest
from seven_jd.jd.api.rest.DropshipDpsSearchsingleorderRequest import DropshipDpsSearchsingleorderRequest
from seven_jd.jd.api.rest.VcItemDynamicFieldGaeaGetRequest import VcItemDynamicFieldGaeaGetRequest
from seven_jd.jd.api.rest.UserRelatedRpcI18nServiceGetOpenIdRequest import UserRelatedRpcI18nServiceGetOpenIdRequest
from seven_jd.jd.api.rest.MiniappIsvCommitMiniAppDevVersionRequest import MiniappIsvCommitMiniAppDevVersionRequest
from seven_jd.jd.api.rest.VcAplsStockUpdateProdStockInfoRequest import VcAplsStockUpdateProdStockInfoRequest
from seven_jd.jd.api.rest.GroupMarketGetMemberInfoRequest import GroupMarketGetMemberInfoRequest
from seven_jd.jd.api.rest.PopJmCenterUserGetEncryptPinNewRequest import PopJmCenterUserGetEncryptPinNewRequest
from seven_jd.jd.api.rest.GroupMarketJoinGroupRequest import GroupMarketJoinGroupRequest
from seven_jd.jd.api.rest.JosOauthRpcXidMixPin2XidRequest import JosOauthRpcXidMixPin2XidRequest
from seven_jd.jd.api.rest.IsvUploadDBOperationLogRequest import IsvUploadDBOperationLogRequest
from seven_jd.jd.api.rest.VenderCategoryGetValidCategoryResultByVenderIdRequest import VenderCategoryGetValidCategoryResultByVenderIdRequest
from seven_jd.jd.api.rest.GetPurchaseInfoRequest import GetPurchaseInfoRequest
from seven_jd.jd.api.rest.PopFwOrderListwithpageRequest import PopFwOrderListwithpageRequest
from seven_jd.jd.api.rest.DataVenderCommonQueryRequest import DataVenderCommonQueryRequest
from seven_jd.jd.api.rest.IsvUploadLoginLogRequest import IsvUploadLoginLogRequest
from seven_jd.jd.api.rest.CertUnlockRequest import CertUnlockRequest
from seven_jd.jd.api.rest.StockWriteUpdateSkuStockRequest import StockWriteUpdateSkuStockRequest
from seven_jd.jd.api.rest.SellerCouponWritePushCouponRequest import SellerCouponWritePushCouponRequest
from seven_jd.jd.api.rest.MiniActivityQueryRequest import MiniActivityQueryRequest
from seven_jd.jd.api.rest.WareProductUpdateQueryRequest import WareProductUpdateQueryRequest
from seven_jd.jd.api.rest.JmOrderGetPayUrlRequest import JmOrderGetPayUrlRequest
from seven_jd.jd.api.rest.PopOrderEnSearchRequest import PopOrderEnSearchRequest
from seven_jd.jd.api.rest.MiniappIsvGetMiniAppCheckVersionRequest import MiniappIsvGetMiniAppCheckVersionRequest
from seven_jd.jd.api.rest.PopOrderEnGetRequest import PopOrderEnGetRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadFindCollectInfoRequest import InteractCenterApiServiceReadFindCollectInfoRequest
from seven_jd.jd.api.rest.ApplyRepealSaveRequest import ApplyRepealSaveRequest
from seven_jd.jd.api.rest.PreviewSaveRequest import PreviewSaveRequest
from seven_jd.jd.api.rest.TemplateReadFindTemplatesByVenderIdRequest import TemplateReadFindTemplatesByVenderIdRequest
from seven_jd.jd.api.rest.PrintingPrintDataSensitivePullDataRequest import PrintingPrintDataSensitivePullDataRequest
from seven_jd.jd.api.rest.TemplateReadFindTemplateByIdRequest import TemplateReadFindTemplateByIdRequest
from seven_jd.jd.api.rest.PrintingTemplateGetTemplateListRequest import PrintingTemplateGetTemplateListRequest
from seven_jd.jd.api.rest.StockReadFindSkuStockRequest import StockReadFindSkuStockRequest
from seven_jd.jd.api.rest.DetectionTextRedLineDetectRequest import DetectionTextRedLineDetectRequest
from seven_jd.jd.api.rest.IsvUploadThirdAppTransmitOrderInfoLogRequest import IsvUploadThirdAppTransmitOrderInfoLogRequest
from seven_jd.jd.api.rest.VenderShopcategoryGetShopCategorysByVenderIdRequest import VenderShopcategoryGetShopCategorysByVenderIdRequest
from seven_jd.jd.api.rest.IsvUploadOrderInfoLogRequest import IsvUploadOrderInfoLogRequest
from seven_jd.jd.api.rest.PointsJosSendPointsRequest import PointsJosSendPointsRequest
from seven_jd.jd.api.rest.PopVenderGetMemberLevelRequest import PopVenderGetMemberLevelRequest
from seven_jd.jd.api.rest.SellerPromotionV2GetRequest import SellerPromotionV2GetRequest
from seven_jd.jd.api.rest.PopGetCommentSummarysRequest import PopGetCommentSummarysRequest
from seven_jd.jd.api.rest.SellerPromotionV2ListRequest import SellerPromotionV2ListRequest
from seven_jd.jd.api.rest.SellerPromotionV2SkuListRequest import SellerPromotionV2SkuListRequest
from seven_jd.jd.api.rest.SellerPromotionV2SkuCountRequest import SellerPromotionV2SkuCountRequest
from seven_jd.jd.api.rest.PopCrmCustomerGetCustomerRequest import PopCrmCustomerGetCustomerRequest
from seven_jd.jd.api.rest.PopOrderFbpSearchRequest import PopOrderFbpSearchRequest
from seven_jd.jd.api.rest.VenderShopQueryRequest import VenderShopQueryRequest
from seven_jd.jd.api.rest.BrandBrandShopFacadeRequest import BrandBrandShopFacadeRequest
from seven_jd.jd.api.rest.TokenToPinCenterConverstionJmEncryptPinRequest import TokenToPinCenterConverstionJmEncryptPinRequest
from seven_jd.jd.api.rest.PopVenderGetVenderLevelRuleRequest import PopVenderGetVenderLevelRuleRequest
from seven_jd.jd.api.rest.PopOrderEncryptMobileNumRequest import PopOrderEncryptMobileNumRequest
from seven_jd.jd.api.rest.MarketServiceListGetRequest import MarketServiceListGetRequest
from seven_jd.jd.api.rest.MiniappApiActivityMiniAppActivityApiUpdateActivityStatusRequest import MiniappApiActivityMiniAppActivityApiUpdateActivityStatusRequest
from seven_jd.jd.api.rest.PopCrmGetMemeberDiscountRequest import PopCrmGetMemeberDiscountRequest
from seven_jd.jd.api.rest.SellerCouponWriteSendCouponRequest import SellerCouponWriteSendCouponRequest
from seven_jd.jd.api.rest.FwMarketPaymentoutRequest import FwMarketPaymentoutRequest
from seven_jd.jd.api.rest.VopAddressConvertFourAreaByDetailStrRequest import VopAddressConvertFourAreaByDetailStrRequest
from seven_jd.jd.api.rest.SellerPromotionV2ApproveRequest import SellerPromotionV2ApproveRequest
from seven_jd.jd.api.rest.MiniappApiActivityMiniAppActivityApiRequest import MiniappApiActivityMiniAppActivityApiRequest
from seven_jd.jd.api.rest.CategoryReadFindValuesByAttrIdUnlimitRequest import CategoryReadFindValuesByAttrIdUnlimitRequest
from seven_jd.jd.api.rest.SellerPromotionV2RemoveRequest import SellerPromotionV2RemoveRequest
from seven_jd.jd.api.rest.SkuReadFindSkuByIdRequest import SkuReadFindSkuByIdRequest
from seven_jd.jd.api.rest.QueryCid3ListByShopId2Request import QueryCid3ListByShopId2Request
from seven_jd.jd.api.rest.PopCrmGetCustomerAllInfoRequest import PopCrmGetCustomerAllInfoRequest
from seven_jd.jd.api.rest.JosMasterKeyGetRequest import JosMasterKeyGetRequest
from seven_jd.jd.api.rest.SellerVenderInfoGetRequest import SellerVenderInfoGetRequest
from seven_jd.jd.api.rest.SellerPromotionV2GetPromoLimitRequest import SellerPromotionV2GetPromoLimitRequest
from seven_jd.jd.api.rest.SkuReadSearchSkuListRequest import SkuReadSearchSkuListRequest
from seven_jd.jd.api.rest.ApplyAddMerchantsAddRequest import ApplyAddMerchantsAddRequest
from seven_jd.jd.api.rest.MarketChargeListGetRequest import MarketChargeListGetRequest
from seven_jd.jd.api.rest.GetDecryptPinRequest import GetDecryptPinRequest
from seven_jd.jd.api.rest.MiniappMixUserInfoRequest import MiniappMixUserInfoRequest
from seven_jd.jd.api.rest.AreasCityGetRequest import AreasCityGetRequest
from seven_jd.jd.api.rest.DropshipDpsModifyStockInfoRequest import DropshipDpsModifyStockInfoRequest
from seven_jd.jd.api.rest.VcItemAdvertiseApplyCreateRequest import VcItemAdvertiseApplyCreateRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponReadOuterServiceQueryWarePageRequest import MarketToolCouponApiServiceCouponReadOuterServiceQueryWarePageRequest
from seven_jd.jd.api.rest.SellerPromotionRemovePromoUsersRequest import SellerPromotionRemovePromoUsersRequest
from seven_jd.jd.api.rest.PromoActivityCountOperatelogRequest import PromoActivityCountOperatelogRequest
from seven_jd.jd.api.rest.DropshipDpsQueryStockInfoRequest import DropshipDpsQueryStockInfoRequest
from seven_jd.jd.api.rest.SellerPromotionCreateRequest import SellerPromotionCreateRequest
from seven_jd.jd.api.rest.PrintingPrintDataPullDataRequest import PrintingPrintDataPullDataRequest
from seven_jd.jd.api.rest.SellerPromotionAppendPromoUsersRequest import SellerPromotionAppendPromoUsersRequest
from seven_jd.jd.api.rest.MiniappRefundRequest import MiniappRefundRequest
from seven_jd.jd.api.rest.VcItemAdvertiseApplyGetRequest import VcItemAdvertiseApplyGetRequest
from seven_jd.jd.api.rest.PopCrmIsPointsEnabledRequest import PopCrmIsPointsEnabledRequest
from seven_jd.jd.api.rest.JdAddressFromAddressGetRequest import JdAddressFromAddressGetRequest
from seven_jd.jd.api.rest.VenderInfoQueryByPinRequest import VenderInfoQueryByPinRequest
from seven_jd.jd.api.rest.MiniappCiserviceYulanRequest import MiniappCiserviceYulanRequest
from seven_jd.jd.api.rest.MiniappCiserviceQueryRequest import MiniappCiserviceQueryRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponBaseReadOuterServiceInitBaseRuleInfoRequest import MarketToolCouponApiServiceCouponBaseReadOuterServiceInitBaseRuleInfoRequest
from seven_jd.jd.api.rest.MiniappMoneyCreateOrderRequest import MiniappMoneyCreateOrderRequest
from seven_jd.jd.api.rest.WareProductbigfieldGetRequest import WareProductbigfieldGetRequest
from seven_jd.jd.api.rest.EdiPoProGetRequest import EdiPoProGetRequest
from seven_jd.jd.api.rest.FollowVenderReadIsFollowByPinAndVidRequest import FollowVenderReadIsFollowByPinAndVidRequest
from seven_jd.jd.api.rest.VcItemAdvertiseApplyUpdateRequest import VcItemAdvertiseApplyUpdateRequest
from seven_jd.jd.api.rest.DropshipDpsPartitionStockIncrementmaintainRequest import DropshipDpsPartitionStockIncrementmaintainRequest
from seven_jd.jd.api.rest.AreasTownGetRequest import AreasTownGetRequest
from seven_jd.jd.api.rest.AreasCountyGetRequest import AreasCountyGetRequest
from seven_jd.jd.api.rest.SvcSettlementInfoRequest import SvcSettlementInfoRequest
from seven_jd.jd.api.rest.AreasProvinceGetRequest import AreasProvinceGetRequest
from seven_jd.jd.api.rest.NewWareBaseproductGetRequest import NewWareBaseproductGetRequest
from seven_jd.jd.api.rest.CertListQueryRequest import CertListQueryRequest
from seven_jd.jd.api.rest.PopJmCenterUserGetOpenIdRequest import PopJmCenterUserGetOpenIdRequest
from seven_jd.jd.api.rest.VcItemPurchasernameGetRequest import VcItemPurchasernameGetRequest
from seven_jd.jd.api.rest.GroupMarketQueryGroupByClusterIdRequest import GroupMarketQueryGroupByClusterIdRequest
from seven_jd.jd.api.rest.VcItemAdvertiseGetRequest import VcItemAdvertiseGetRequest
from seven_jd.jd.api.rest.DropshipDpsPartitionStockStoreQueryRequest import DropshipDpsPartitionStockStoreQueryRequest
from seven_jd.jd.api.rest.FollowVenderReadQueryForCountByVidRequest import FollowVenderReadQueryForCountByVidRequest
from seven_jd.jd.api.rest.VcItemAttrApplyUpdateRequest import VcItemAttrApplyUpdateRequest
from seven_jd.jd.api.rest.VcItemAttrApplyCreateRequest import VcItemAttrApplyCreateRequest
from seven_jd.jd.api.rest.FollowVenderWriteFollowByPinAndVidRequest import FollowVenderWriteFollowByPinAndVidRequest
from seven_jd.jd.api.rest.VcItemAttrApplyGetRequest import VcItemAttrApplyGetRequest
from seven_jd.jd.api.rest.VcItemAttrAppliesFindRequest import VcItemAttrAppliesFindRequest
from seven_jd.jd.api.rest.EdiSdvWarePerformancedataGetRequest import EdiSdvWarePerformancedataGetRequest
from seven_jd.jd.api.rest.VssReportJosSearchBrandPerformanceInfoRequest import VssReportJosSearchBrandPerformanceInfoRequest
from seven_jd.jd.api.rest.PopVideoInfoGetRequest import PopVideoInfoGetRequest
from seven_jd.jd.api.rest.VcItemAttrGetRequest import VcItemAttrGetRequest
from seven_jd.jd.api.rest.TemplateWriteBindWareRequest import TemplateWriteBindWareRequest
from seven_jd.jd.api.rest.JosVoucherInfoGetRequest import JosVoucherInfoGetRequest
from seven_jd.jd.api.rest.WarehouseInboundOrderQueryListRequest import WarehouseInboundOrderQueryListRequest
from seven_jd.jd.api.rest.IsvAddisvlogRequest import IsvAddisvlogRequest
from seven_jd.jd.api.rest.VcItemAdvertiseAppliesFindRequest import VcItemAdvertiseAppliesFindRequest
from seven_jd.jd.api.rest.SellerCouponReadFindCouponRequest import SellerCouponReadFindCouponRequest
from seven_jd.jd.api.rest.VcItemSaleunitsFindRequest import VcItemSaleunitsFindRequest
from seven_jd.jd.api.rest.WareReadSearchWare4ValidRequest import WareReadSearchWare4ValidRequest
from seven_jd.jd.api.rest.DataVenderPreciseRecomImageUploadRequest import DataVenderPreciseRecomImageUploadRequest
from seven_jd.jd.api.rest.VcItemSalernameGetRequest import VcItemSalernameGetRequest
from seven_jd.jd.api.rest.PopCrmGetVenderPointsRuleRequest import PopCrmGetVenderPointsRuleRequest
from seven_jd.jd.api.rest.NewWareProductsortattGetRequest import NewWareProductsortattGetRequest
from seven_jd.jd.api.rest.PopCrmGetPointsDetailByFlowRequest import PopCrmGetPointsDetailByFlowRequest
from seven_jd.jd.api.rest.WareReadFindWareByIdRequest import WareReadFindWareByIdRequest
from seven_jd.jd.api.rest.WarehouseOutboundOrderQueryListRequest import WarehouseOutboundOrderQueryListRequest
from seven_jd.jd.api.rest.WarehouseOutboundOrderQueryDetailWareRequest import WarehouseOutboundOrderQueryDetailWareRequest
from seven_jd.jd.api.rest.NewWareAttributeValuesQueryRequest import NewWareAttributeValuesQueryRequest
from seven_jd.jd.api.rest.InnovationProductReadGetSkuListRequest import InnovationProductReadGetSkuListRequest
